# 使用baostock库获取股票数据
from datetime import datetime, date

import baostock as bs
import pandas as pd

from yangke.common.config import logger


def get_holiday(day_datetime: datetime.date = date.today()) -> pd.DataFrame:
    """
    获取股票交易日历
    """
    year = day_datetime.year
    bs.login()
    holiday_data: pd.DataFrame = bs.query_trade_dates(start_date=f'{year}-01-01',
                                                      end_date=f'{year}-12-31').get_data()
    bs.logout()
    if len(holiday_data) == 0:
        logger.error('获取假日数据出错，检查baostock版本')
    holiday_data.rename(columns={"calendar_date": "date", "is_trading_day": "open"}, inplace=True)
    # 日期必须转换为datetime才能与数据库中的DATE列匹配
    holiday_data["date"] = pd.to_datetime(holiday_data["date"])
    holiday_data["open"] = holiday_data["open"].apply(lambda x: True if int(x) == 1 else False)
    return holiday_data
